@@ -33,16 +33,16 @@ using namespace KCalCore;
 using namespace KCalUtils;
 
 //@cond PRIVATE
-struct KCalUtils::Scheduler::Private {
+struct KCalUtils::SchedulerPrivate {
 public:
-    Private() : mFreeBusyCache(Q_NULLPTR)
+    SchedulerPrivate() : mFreeBusyCache(Q_NULLPTR)
     {
     }
     FreeBusyCache *mFreeBusyCache;
 };
 //@endcond
 
-Scheduler::Scheduler(const Calendar::Ptr &calendar) : d(new KCalUtils::Scheduler::Private)
+Scheduler::Scheduler(const Calendar::Ptr &calendar) : d(new KCalUtils::SchedulerPrivate)
 {
     mCalendar = calendar;
     mFormat = new ICalFormat();
@@ -251,7 +251,7 @@ bool Scheduler::acceptRequest(const IncidenceBase::Ptr &incidence,
                    "<item>you no longer have access to the calendar containing the invitation</item>"
                    "</list></para>"
                    "<para>This is not a problem, but we thought you should know.</para>"),
-            i18nc("@title", "Cannot find invitation to be updated"), QLatin1String("AcceptCantFindIncidence"));
+            i18nc("@title", "Cannot find invitation to be updated"), QStringLiteral("AcceptCantFindIncidence"));
     }
     qCDebug(KCALUTILS_LOG) << "Storing new incidence with scheduling uid=" << inc->schedulingID()
                            << " and uid=" << inc->uid();
